@@ -20,7 +20,7 @@ class ExecutionContext(object):
     """
     An instance of this class is able to execute a script in some
     particular language. This is somewhat abstract and must be
-    subclassed and attached to a database, or a (remote) shell...
+    subclassed and attached to a database...
 
     Another responsibility of this class instances is to keep
     a persistent knowledge about last applied revision of
@@ -30,6 +30,7 @@ class ExecutionContext(object):
     language_name = None
 
     execution_contexts_registry = {}
+    user_assertions = {}
 
     @classmethod
     def for_language(cls, language):
@@ -78,12 +79,29 @@ class ExecutionContext(object):
         Do nothing, used by doctests.
         """
 
+    def addAssertions(self, assertions):
+        """
+        Add given `assertions` to the set of assertions managed by the context.
+        """
+
+        for assertion in assertions:
+            if "=" in assertion:
+                assertion, state = assertion.split('=')
+                state = state.lower() in ('true', 't', '1', 'yes', 'y')
+            else:
+                state = True
+            if assertion in self.assertions:
+                raise ValueError(u'Cannot override existing "%s" assertion' %
+                                 assertion)
+            self.user_assertions[assertion] = state
+
     def verifyCondition(self, condition):
         """
         Verify given `condition`, returning False if it is not satisfied.
         """
 
-        return self.assertions.get(condition, False)
+        return (self.assertions.get(condition, False)
+                or self.user_assertions.get(condition, False))
 
     def apply(self, patch, options):
         "Try to execute the given `patch` script"
