@@ -45,6 +45,10 @@ def main():
     parser.add_argument("--assume-already-applied", default=False, action="store_true",
                         help=u"Assume missing patches are already applied, do not"
                         " re-execute them.")
+    parser.add_argument("-a", "--assert", metavar="NAME", action="append", dest="assertions",
+                        help="Introduce an arbitrary assertion usable as a pre-condition"
+                        " by the scripts. NAME may be a simple string or something like"
+                        " ``production=true``. This option may be given multiple times.")
     parser.add_argument("-n", "--dry-run", default=False, action="store_true",
                         help=u"Don't apply patches, just list them.")
     parser.add_argument("-v", "--verbose", default=False, action="store_true",
@@ -81,7 +85,7 @@ def main():
     elif args.mysql:
         from .contexts.mysql import MySQLContext
         sqlctx = MySQLContext(host=args.host, db=args.mysql,
-                                 username=args.username, password=args.password)
+                              username=args.username, password=args.password)
     else:
         print(u"You must select exactly one database with either '--postgres',"
               u" '--firebird', '--sqlalchemy' or '--mysql'!")
@@ -93,6 +97,13 @@ def main():
         print(u"Option --patch-storage is mandatory")
         return 128
 
+    if args.assertions:
+        try:
+            sqlctx.addAssertions(args.assertions)
+        except ValueError as e:
+            print(u"Invalid assertion: %s" % e)
+            return 128
+
     patches = pm.neededPatches(sqlctx)
     execute = ExecutionContext.execute
 
