@@ -205,7 +205,7 @@ class ScriptDirective(Directive):
             # Place a topic, that will be the target of the references
             # to this script
             topic = Script('', title, classes=["script"])
-            topic.scriptid = scriptid
+            topic['scriptid'] = scriptid
             topicid = nodes.make_id('script ' + scriptid)
             name = nodes.fully_normalize_name(caption.astext())
             if not state.document.has_name(name):
@@ -344,9 +344,10 @@ def add_scripts_crossrefs(app, doctree, fromdocname):
 
     # Add scripts details
     for node in doctree.traverse(Script):
-        patch = scripts[node.scriptid]['patch']
+        patch = scripts[node['scriptid']]['patch']
 
         dlist = nodes.definition_list()
+
         try:
             add_detail(dlist, 'depends on', patch.depends)
             add_detail(dlist, 'preceeds', patch.preceeds)
@@ -355,6 +356,34 @@ def add_scripts_crossrefs(app, doctree, fromdocname):
             raise DependencyError(u'%s (defined in %s at line %s)'
                                   u' references an unknown script "%s"'
                                   % (patch, patch.source, patch.line, e))
+
+        if patch.conditions:
+            item = nodes.definition_list_item()
+            if len(patch.conditions)>1:
+                item += nodes.term('', 'conditions')
+                clist = nodes.bullet_list()
+                for c in patch.conditions:
+                    li = nodes.list_item()
+                    li += nodes.paragraph('', c)
+                    clist += li
+                item += nodes.definition('', clist)
+            else:
+                item += nodes.term('', 'condition')
+                item += nodes.definition('', nodes.paragraph('', patch.conditions[0]))
+            dlist += item
+
+        if patch.always:
+            item = nodes.definition_list_item()
+            item += nodes.term('', 'execute always')
+            if patch.always == 'first':
+                value = nodes.paragraph('', "Before any other script")
+            elif patch.always == 'last':
+                value = nodes.paragraph('', "After any other script")
+            else:
+                value = nodes.paragraph('', patch.always)
+            item += nodes.definition('', value)
+            dlist += item
+
         if patch.onerror != 'abort':
             item = nodes.definition_list_item()
             item += nodes.term('', 'errors policy')
